Properties Methods Events Direct Link

# Class Ext.ensible.cal.CalendarCombo

Package: | Ext.ensible.cal
Defined In: | CalendarCombo.js
Class: | CalendarCombo
Extends: | Object

A custom combo used for choosing from the list of available calendars to assign an event to. You must pass a populated calendar store as the store config or the combo will not work.

This is pretty much a standard combo that is simply pre-configured for the options needed by the calendar components. The default configs are as follows:

    fieldLabel: 'Calendar',
    triggerAction: 'all',
    mode: 'local',
    forceSelection: true,
    width: 200

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.